# IO Module

The `wandas.io` module provides reading and writing capabilities for various file formats.

## File Readers

Provides functionality to read data from various file formats.

::: wandas.io.readers

## WAV File IO

Provides functions for reading and writing WAV files.

::: wandas.io.wav_io

## WDF File IO

Provides functions for reading and writing WDF (Wandas Data File) format, which enables complete preservation including metadata.

::: wandas.io.wdf_io
